"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Neo4jBoltSession = void 0;
const Logger = __importStar(require("../logger"));
const parse_result_1 = require("../parse_result");
class Neo4jBoltSession {
    constructor(session, options) {
        this.session = session;
        this.options = options;
    }
    execute(query, options = {}) {
        return this.execWithParams(query, {}, options);
    }
    execWithParams(query, params, options = {}) {
        const startTime = Date.now();
        return new Promise((resolve, reject) => {
            const parsedRecords = [];
            this.session.run(query, params).subscribe({
                onCompleted: () => {
                    if (options.singularOutput) {
                        resolve(parsedRecords[0]);
                    }
                    else {
                        resolve(parsedRecords);
                    }
                    this.session.close();
                    Logger.logQuery(query, Date.now() - startTime, { logLevel: this.options.logLevel });
                },
                onError: (error) => {
                    reject(error);
                    this.session.close();
                    Logger.logQuery(query, Date.now() - startTime, { logLevel: this.options.logLevel, isError: true });
                },
                onNext: (record) => {
                    const stringFormatter = Object.keys(options).indexOf("stringFormatter") > -1 ?
                        options.stringFormatter
                        :
                            this.options.stringFormatter;
                    const parsedRecord = (0, parse_result_1.parseNeo4jResult)(record, stringFormatter);
                    if (options.singularOutput && parsedRecords.length > 1) {
                        reject(new Error(`multiple records returned in signular mode`));
                        return this.session.close();
                    }
                    parsedRecords.push(parsedRecord);
                    return Promise.resolve();
                },
            });
        });
    }
    commit() {
        return Promise.resolve();
    }
    rollback() {
        return Promise.resolve();
    }
    isOpen() {
        return false;
    }
}
exports.Neo4jBoltSession = Neo4jBoltSession;
//# sourceMappingURL=bolt_session.js.map