"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Neo4jClient = void 0;
const Neo4j = __importStar(require("neo4j-driver"));
const bolt_session_1 = require("./bolt/bolt_session");
const bolt_transactional_session_1 = require("./bolt/bolt_transactional_session");
const options_interface_1 = require("./types/options.interface");
class Neo4jClient {
    constructor(options) {
        this.options = getCompleteClientOptions(options);
        const authToken = getAuthenticationToken(this.options.authentication);
        this.client = Neo4j.driver(`${options.protocol}://${options.host}:${options.port}`, authToken, {
            connectionTimeout: options.connectionTimeout,
            maxConnectionPoolSize: options.connectionLimit,
        });
        // TODO: add implementation for other protocols
    }
    getSession() {
        const session = this.client.session();
        return new bolt_session_1.Neo4jBoltSession(session, {
            logLevel: this.options.logLevel,
            stringFormatter: this.options.stringFormatter,
        });
    }
    getTransactionalSession() {
        const session = this.client.session();
        return new bolt_transactional_session_1.Neo4jBoltTransactionalSession(session, {
            logLevel: this.options.logLevel,
            stringFormatter: this.options.stringFormatter,
        });
    }
}
exports.Neo4jClient = Neo4jClient;
const DEFAULT_BOLT_OPTIONS = {
    authentication: {},
    connectionLimit: 8,
    connectionTimeout: 60 * 1000,
    logLevel: options_interface_1.LogLevel.ERROR,
    logTimed: true,
    port: 7687,
    protocol: options_interface_1.Neo4jConnectionProtocol.BOLT,
    stringFormatter: (value) => value,
};
function getCompleteClientOptions(partialOptions) {
    if (!partialOptions.protocol || partialOptions.protocol === options_interface_1.Neo4jConnectionProtocol.BOLT) {
        return { ...DEFAULT_BOLT_OPTIONS, ...partialOptions };
    }
    else {
        throw new Error("HTTP session not implemented yet");
    }
}
function getAuthenticationToken(authentication) {
    if (authentication.username && authentication.password) {
        return Neo4j.auth.basic(authentication.username, authentication.password);
    }
    else if (authentication.ticket) {
        const credentialsString = Buffer.from(authentication.ticket, "base64").toString();
        const [username, password] = credentialsString.split(":");
        return Neo4j.auth.basic(username, password);
    }
    return undefined;
}
//# sourceMappingURL=client.js.map