"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseNeo4jResult = void 0;
function parseNeo4jResult(result, resultUnescaper) {
    if (typeof result === "boolean"
        || typeof result === "number"
        || result === null) {
        return result;
    }
    else if (typeof result === "string") {
        if (resultUnescaper) {
            try {
                return resultUnescaper(result);
            }
            catch {
                return result;
            }
        }
        else {
            return result;
        }
    }
    if (Array.isArray(result)) {
        return result.map((item) => parseNeo4jResult(item, resultUnescaper));
    }
    if (!result.constructor || !result.constructor.name) {
        throw new Error(`invalid data type: ${result}`);
    }
    switch (result.constructor.name) {
        case "Record":
            const record = result;
            const parsedRecord = {};
            for (const key of record.keys) {
                parsedRecord[key] = parseNeo4jResult(record.get(key), resultUnescaper);
            }
            return parsedRecord;
        case "Integer":
            const integer = result;
            return integer.toNumber();
        case "Node":
            const node = result;
            return Object.assign(parseNeo4jResult(node.properties, resultUnescaper), { _id: node.identity.toNumber() });
        case "Relationship":
            const relationship = result;
            return parseNeo4jResult(relationship.properties, resultUnescaper);
        case "Path":
        case "PathSegment":
        case "Date":
        case "Time":
        case "LocalTime":
        case "DateTime":
        case "LocalDateTime":
        case "Duration":
            return result; // TODO: complete implementation for each
        case "Point":
            const point = result;
            return { x: point.x, y: point.y, z: point.z };
        default:
            const output = {};
            for (const key of Object.keys(result)) {
                output[key] = parseNeo4jResult(result[key], resultUnescaper);
            }
            return output;
    }
}
exports.parseNeo4jResult = parseNeo4jResult;
//# sourceMappingURL=parse_result.js.map